#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dotgen
version:              0.4.3
visibility:           public
id:                   dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
key:                  dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
license:              BSD-3-Clause
maintainer:           Andy Gill <andygill@ku.edu>
author:               Andy Gill
stability:            alpha
homepage:             https://github.com/ku-fpg/dotgen
synopsis:             A simple interface for building .dot graph files.
description:
    This package provides a simple interface for building .dot graph files,
    for input into the dot and graphviz tools.
    It includes a monadic interface for building graphs.

category:             Text
abi:                  390fb478c86abe57bb5ef1a31bca976a
exposed:              True
exposed-modules:      Text.Dot
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dotgen-0.4.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dotgen-0.4.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dotgen-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dotgen
hs-libraries:         HSdotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
depends:              base-4.18.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-dotgen/html/dotgen.haddock
haddock-html:         /usr/share/doc/haskell-dotgen/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

